@@ -5,6 +5,6 @@ register = template.Library()
 
 
 @register.inclusion_tag('feedback/feedback.html', takes_context=False)
-def show_feedback():
-    form = get_feedback_form()()
+def show_feedback(key='default'):
+    form = get_feedback_form(key)()
     return locals()
